==> k3sup-0.12.0.tar.gz: k3sup-0.12.0/.github/ISSUE_TEMPLATE.md <==
<!--- Provide a general summary of the issue in the Title above -->

## Expected Behaviour
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behaviour
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

## Are you a GitHub Sponsor (Yes/No?)

<!--- Check at https://github.com/sponsors/alexellis -->

- [ ] Yes
- [ ] No

## Possible Solution
<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- or ideas how to implement the addition or change -->


## Steps to Reproduce
<!--- Provide a link to a live example, or an unambiguous set of steps to -->
<!--- reproduce this bug. Include code to reproduce, if relevant -->
1.
2.
3.
4.

## Context
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

## Your Environment

* What Kubernetes distribution are you using?

```
kubectl version
```

* What OS or type or VM are you using for your cluster? Where is it hosted? (for `k3sup install/join`):

* Operating System and version (e.g. Linux, Windows, MacOS):

```
uname -a

cat /etc/os-release
```

## "Be part of the solution"

Subject to approval, are you willing to work on a Pull Request for this issue or feature request?

- [ ] Yes
- [ ] No

==> k3sup-0.12.1.tar.gz: k3sup-0.12.1/.github/ISSUE_TEMPLATE.md <==
<!--- Provide a general summary of the issue in the Title above -->

## Expected Behaviour
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behaviour
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

## Are you a GitHub Sponsor (Yes/No?)

Due to limited resources, we can only respond to requests from sponsors

<!--- Check at https://github.com/sponsors/alexellis -->

- [ ] Yes
- [ ] No

## Possible Solution
<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- or ideas how to implement the addition or change -->


## Steps to Reproduce
<!--- Provide a link to a live example, or an unambiguous set of steps to -->
<!--- reproduce this bug. Include code to reproduce, if relevant -->
1.
2.
3.
4.

## Context
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

## Your Environment

* k3sup version:

```
k3sup version
```

* What Kubernetes distribution, client and server version are you using?

```
kubectl version
```

* What OS or type or VM are you using for your cluster? Where is it hosted? (for `k3sup install/join`):

* Operating System and version (e.g. Linux, Windows, MacOS):

```
uname -a

cat /etc/os-release
```

## "Be part of the solution"

Subject to approval, are you willing to work on a Pull Request for this issue or feature request?

- [ ] Yes
- [ ] No
